# correlacao

Description. 
The package correlacao is used to:

	- Plot correlations between variable and target.
	- The methods used are: Spearman e Pearson.

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install correlacao

```bash
pip install correlacao
```

## Usage:

	- The module spearman_pearson receive with entry a DataFrame with variables and a Serie as target.
	- Ex: ''' from correlacao import spearman_pearson as sp

              sp.start(DataFrame, Target)  '''
## Author
Nicodemos Freitas

## License
[MIT](https://choosealicense.com/licenses/mit/)
